@@ -2,26 +2,26 @@
 datazen - A class for adding manifest-loading to environments.
 """
 
-from io import StringIO
-
 # built-in
 import logging
 import os
-from typing import List, Tuple
+from typing import List, Tuple, Type
 
 # third-party
-from cerberus import Validator
 from vcorelib.dict import merge_dicts
 from vcorelib.dict.env import dict_resolve_env_vars
-from vcorelib.io import ARBITER
+from vcorelib.paths import resource
+from vcorelib.schemas import CerberusSchema
+from vcorelib.schemas.base import Schema
 
 # internal
-from datazen import DEFAULT_DIR, ROOT_NAMESPACE
+from datazen import DEFAULT_DIR, PKG_NAME, ROOT_NAMESPACE
 from datazen.classes.target_resolver import TargetResolver
+from datazen.classes.valid_dict import ValidDict
 from datazen.environment.config import ConfigEnvironment
 from datazen.environment.template import TemplateEnvironment
 from datazen.parsing import load as load_raw
-from datazen.paths import get_package_data, get_package_dir, resolve_dir
+from datazen.paths import resolve_dir
 from datazen.schemas import inject_custom_schemas, load_types
 
 LOG = logging.getLogger(__name__)
@@ -89,6 +89,7 @@ class ManifestEnvironment(ConfigEnvironment, TemplateEnvironment):
         rel_path: str,
         namespace: str = ROOT_NAMESPACE,
         allow_dup: bool = False,
+        load_defaults: bool = True,
     ) -> None:
         """
         Looks for keys matching types of directories that can be loaded
@@ -108,7 +109,7 @@ class ManifestEnvironment(ConfigEnvironment, TemplateEnvironment):
             # if a directory list isn't provided, and the directory of the
             # same name of the key is present in the manifest directory,
             # load it
-            elif os.path.isdir(os.path.join(rel_path, key)):
+            elif os.path.isdir(os.path.join(rel_path, key)) and load_defaults:
                 handler([key], rel_path, namespace, allow_dup)
 
     def default_target(self) -> str:
@@ -161,7 +162,7 @@ class ManifestEnvironment(ConfigEnvironment, TemplateEnvironment):
         curr_manifest, loaded, _ = load_raw(path, params, {})
 
         # update params, load again so we can use self-referential params
-        if "params" in curr_manifest:
+        if loaded and "params" in curr_manifest:
             params = merge_dicts(
                 [params, dict_resolve_env_vars(curr_manifest["params"])]
             )
@@ -172,7 +173,12 @@ class ManifestEnvironment(ConfigEnvironment, TemplateEnvironment):
 
         # load the data directories before resolving includes
         rel_path = os.path.dirname(path)
-        self.load_dirs(curr_manifest, rel_path, allow_dup=True)
+        self.load_dirs(
+            curr_manifest,
+            rel_path,
+            allow_dup=True,
+            load_defaults=curr_manifest.get("default_dirs", True),
+        )
         self.update_task_dirs(curr_manifest, rel_path)
 
         # resolve includes
@@ -188,7 +194,7 @@ class ManifestEnvironment(ConfigEnvironment, TemplateEnvironment):
                 all_manifests.append(result[0])
 
         # merge include data
-        curr_manifest = merge_dicts(all_manifests)
+        curr_manifest = merge_dicts(all_manifests, expect_overwrite=True)
 
         return curr_manifest, True
 
@@ -243,18 +249,12 @@ class ManifestEnvironment(ConfigEnvironment, TemplateEnvironment):
 
 def get_manifest_schema(
     require_all: bool = True,
-    logger: logging.Logger = LOG,
-) -> Validator:
+    cls: Type[Schema] = CerberusSchema,
+) -> Schema:
     """Load the schema for manifest from the package."""
 
-    return Validator(
-        ARBITER.decode_stream(
-            "yaml",
-            StringIO(
-                get_package_data(os.path.join("schemas", "manifest.yaml"))
-            ),
-            logger,
-        ).data,
+    return cls.from_path(
+        resource("schemas", "manifest.yaml", package=PKG_NAME),
         require_all=require_all,
     )
 
@@ -262,13 +262,15 @@ def get_manifest_schema(
 def validate_manifest(manifest: dict, logger: logging.Logger = LOG) -> bool:
     """Validate manifest data against the package schema."""
 
-    custom_schemas = load_types([get_package_dir("schema_types")])
+    schemas = resource("schema_types", package=PKG_NAME)
+    assert schemas is not None
 
-    with inject_custom_schemas(custom_schemas):
-        schema = get_manifest_schema(False, logger)
-        result = schema.validate(manifest)
+    with inject_custom_schemas(load_types([schemas])):
+        result = ValidDict(
+            "manifest",
+            manifest,
+            get_manifest_schema(require_all=False),
+            logger=logger,
+        )
 
-    if not result:
-        logger.error("invalid manifest: %s", schema.errors)
-
-    return result
+    return result.valid
